@@ -1,5 +1,4 @@
 #-------------------------------------------------------------------------------
-# $Id$
 #
 # Project: EOxServer <http://eoxserver.org>
 # Authors: Stephan Krause <stephan.krause@eox.at>
@@ -11,8 +10,8 @@
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
 # in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
-# copies of the Software, and to permit persons to whom the Software is 
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
 # furnished to do so, subject to the following conditions:
 #
 # The above copyright notice and this permission notice shall be included in all
@@ -31,18 +30,19 @@
 Django settings for EOxServer's {{ project_name }} instance.
 
 For more information on this file, see
-https://docs.djangoproject.com/en/1.4/topics/settings/
+https://docs.djangoproject.com/en/1.11/topics/settings/
 
 For the full list of settings and their values, see
-https://docs.djangoproject.com/en/1.4/ref/settings/
+https://docs.djangoproject.com/en/1.11/ref/settings/
 """
 
+import os
 from os.path import join, abspath, dirname
 
 PROJECT_DIR = dirname(abspath(__file__))
 PROJECT_URL_PREFIX = ''
 
-TEST_RUNNER = 'eoxserver.testing.core.EOxServerTestRunner'
+#TEST_RUNNER = 'eoxserver.testing.core.EOxServerTestRunner'
 
 DEBUG = True
 TEMPLATE_DEBUG = DEBUG
@@ -53,19 +53,36 @@ ADMINS = (
 
 MANAGERS = ADMINS
 
-DATABASES = {
-    'default': {
-        'ENGINE': 'django.contrib.gis.db.backends.spatialite',                      # Use 'spatialite' or change to 'postgis'.
-        'NAME': '{{ project_directory }}/{{ project_name }}/data/config.sqlite',    # Or path to database file if using spatialite.
-        #'TEST_NAME': '{{ project_directory }}/{{ project_name }}/data/test-config.sqlite', # Required for certain test cases, but slower!
-        'USER': '',                                                             # Not used with spatialite.
-        'PASSWORD': '',                                                         # Not used with spatialite.
-        'HOST': '',                                                             # Set to empty string for localhost. Not used with spatialite.
-        'PORT': '',                                                             # Set to empty string for default. Not used with spatialite.
+# Configure which database to use.
+db_type = os.environ.get('DB')
+if db_type == 'postgis':
+    DATABASES = {
+        'default': {
+            'ENGINE': 'django.contrib.gis.db.backends.postgis',
+            'HOST': os.environ['DB_HOST'],
+            'NAME': os.environ['DB_NAME'],
+            'USER': os.environ['DB_USER'],
+            'PASSWORD': os.environ['DB_PW'],
+        }
+    }
+elif db_type == 'spatialite':
+    spatialite_path = os.environ.get('SPATIALITE_PATH', 'data/config.sqlite')
+    DATABASES = {
+        'default': {
+            'ENGINE': 'django.contrib.gis.db.backends.spatialite',
+            'NAME': join(PROJECT_DIR, spatialite_path),
+        }
     }
-}
 
-SPATIALITE_SQL = join(PROJECT_DIR, 'data/init_spatialite-2.3.sql')
+    SPATIALITE_SQL = join(PROJECT_DIR, 'data/init_spatialite-2.3.sql')
+    SPATIALITE_LIBRARY_PATH = 'mod_spatialite.so'
+
+# Hosts/domain names that are valid for this site; required if DEBUG is False
+# See https://docs.djangoproject.com/en/1.5/ref/settings/#allowed-hosts
+if 'ALLOWED_HOSTS' in os.environ:
+    ALLOWED_HOSTS = os.environ['ALLOWED_HOSTS'].split()
+else:
+    ALLOWED_HOSTS = []
 
 # Local time zone for this installation. Choices can be found here:
 # http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
@@ -75,7 +92,7 @@ SPATIALITE_SQL = join(PROJECT_DIR, 'data/init_spatialite-2.3.sql')
 # dates/times -- not necessarily the timezone of the server.
 # If you are using UTC (Zulu) time zone for your data (e.g. most
 # satellite imagery) it is highly recommended to use 'UTC' here. Otherwise
-# you will encounter time-shifts between your data, search request & the 
+# you will encounter time-shifts between your data, search request & the
 # returned results.
 TIME_ZONE = 'UTC'
 
@@ -97,22 +114,22 @@ USE_L10N = True
 USE_TZ = True
 
 # Absolute filesystem path to the directory that will hold user-uploaded files.
-# Example: "/home/media/media.lawrence.com/media/"
+# Example: "/var/www/example.com/media/"
 MEDIA_ROOT = ''
 
 # URL that handles the media served from MEDIA_ROOT. Make sure to use a
 # trailing slash.
-# Examples: "http://media.lawrence.com/media/", "http://example.com/media/"
+# Examples: "http://example.com/media/", "http://media.example.com/"
 MEDIA_URL = ''
 
 # Absolute path to the directory static files should be collected to.
 # Don't put anything in this directory yourself; store your static files
 # in apps' "static/" subdirectories and in STATICFILES_DIRS.
-# Example: "/home/media/media.lawrence.com/static/"
+# Example: "/var/www/example.com/static/"
 STATIC_ROOT = join(PROJECT_DIR, 'static')
 
 # URL prefix for static files.
-# Example: "http://media.lawrence.com/static/"
+# Example: "http://example.com/static/", "http://static.example.com/"
 STATIC_URL = '/{{ project_name }}_static/'
 
 # Additional locations of static files
@@ -133,12 +150,38 @@ STATICFILES_FINDERS = (
 # Make this unique, and don't share it with anybody.
 SECRET_KEY = '{{ secret_key }}'
 
-# List of callables that know how to import templates from various sources.
-TEMPLATE_LOADERS = (
-    'django.template.loaders.filesystem.Loader',
-    'django.template.loaders.app_directories.Loader',
-#     'django.template.loaders.eggs.Loader',
-)
+DEFAULT_AUTO_FIELD = 'django.db.models.BigAutoField'
+
+TEMPLATES = [
+    {
+        'BACKEND': 'django.template.backends.django.DjangoTemplates',
+        'DIRS': [],
+        'APP_DIRS': True,
+        'OPTIONS': {
+            'context_processors': [
+                'django.template.context_processors.debug',
+                'django.template.context_processors.request',
+                'django.contrib.auth.context_processors.auth',
+                'django.contrib.messages.context_processors.messages',
+            ],
+        },
+    },
+]
+
+MIDDLEWARE = [
+    'django_prometheus.middleware.PrometheusBeforeMiddleware',
+    'django.middleware.security.SecurityMiddleware',
+    'django.contrib.sessions.middleware.SessionMiddleware',
+    'django.middleware.common.CommonMiddleware',
+    'django.middleware.csrf.CsrfViewMiddleware',
+    'django.contrib.auth.middleware.AuthenticationMiddleware',
+    # 'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
+    'django.contrib.messages.middleware.MessageMiddleware',
+    'django.middleware.clickjacking.XFrameOptionsMiddleware',
+    # # For management of the per/request cache system.
+    # 'eoxserver.backends.middleware.BackendsCacheMiddleware',
+    'django_prometheus.middleware.PrometheusAfterMiddleware',
+]
 
 MIDDLEWARE_CLASSES = (
     'django.middleware.common.CommonMiddleware',
@@ -148,6 +191,9 @@ MIDDLEWARE_CLASSES = (
     'django.contrib.messages.middleware.MessageMiddleware',
     # Uncomment the next line for simple clickjacking protection:
     # 'django.middleware.clickjacking.XFrameOptionsMiddleware',
+
+    # For management of the per/request cache system.
+    'eoxserver.backends.middleware.BackendsCacheMiddleware',
 )
 
 ROOT_URLCONF = '{{ project_name }}.urls'
@@ -155,13 +201,6 @@ ROOT_URLCONF = '{{ project_name }}.urls'
 # Python dotted path to the WSGI application used by Django's runserver.
 WSGI_APPLICATION = '{{ project_name }}.wsgi.application'
 
-TEMPLATE_DIRS = (
-    # Put strings here, like "/home/html/django_templates" or "C:/www/django/templates".
-    # Always use forward slashes, even on Windows.
-    # Don't forget to use absolute paths, not relative paths.
-    join(PROJECT_DIR, 'templates'),
-)
-
 INSTALLED_APPS = (
     'django.contrib.auth',
     'django.contrib.contenttypes',
@@ -176,17 +215,33 @@ INSTALLED_APPS = (
     'django.contrib.admindocs',
     # Enable the databrowse:
     #'django.contrib.databrowse',
-#    'django_extensions',
+    # Enable for better schema and data-migrations
+    #'south',
+    # Enable for debugging
+    #'django_extensions',
+   'django_prometheus',
     # Enable EOxServer:
     'eoxserver.core',
     'eoxserver.services',
     'eoxserver.resources.coverages',
-    'eoxserver.resources.processes',
     'eoxserver.backends',
     'eoxserver.testing',
     'eoxserver.webclient'
 )
 
+
+# The configured EOxServer components. Components add specific functionality
+# to the EOxServer and must adhere to a given interface. In order to activate
+# a component, its module must be included in the following list or imported at
+# some other place. To help configuring all required components, each module
+# path can end with either a '*' or '**'. The single '*' means that all direct
+# modules in the package will be included. With the double '**' a recursive
+# search will be done.
+COMPONENTS = (
+    # not used anymore
+)
+
+
 # A sample logging configuration. The only tangible logging
 # performed by this configuration is to send an email to
 # the site admins on every HTTP 500 error when DEBUG=False.
@@ -213,9 +268,15 @@ LOGGING = {
             'level': 'DEBUG',
             'class': 'logging.FileHandler',
             'filename': join(PROJECT_DIR, 'logs', 'eoxserver.log'),
-            'formatter': 'verbose',
+            'formatter': 'verbose' if DEBUG else 'simple',
             'filters': [],
-        }
+        },
+        'stderr_stream': {
+            'level': 'INFO',
+            'class': 'logging.StreamHandler',
+            'formatter': 'simple',
+            'filters': [],
+        },
     },
     'loggers': {
         'eoxserver': {
@@ -223,6 +284,11 @@ LOGGING = {
             'level': 'DEBUG' if DEBUG else 'INFO',
             'propagate': False,
         },
+        'django': {
+            'handlers': ['stderr_stream'],
+            'level': 'WARNING',
+            'propagate': False,
+        },
     }
 }
 
@@ -230,6 +296,6 @@ FIXTURE_DIRS = (
     join(PROJECT_DIR, 'data/fixtures'),
 )
 
-# Set this variable if the path to the instance cannot be resolved 
+# Set this variable if the path to the instance cannot be resolved
 # automatically, e.g. in case of redirects
 #FORCE_SCRIPT_NAME="/path/to/instance/"
